package com.pj.bank_info;

import java.util.List;

import cn.hutool.crypto.digest.HMac;
import cn.hutool.crypto.digest.HmacAlgorithm;
import cn.hutool.log.StaticLog;
import com.pj.rabbitmq.MessageSender;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;

import javax.annotation.Resource;


/**
 * Controller: bank_info -- 银行回执信息表
 * @author lbl
 */
@RestController
@RequestMapping("/BankInfo/")
public class BankInfoController {

	/** 底层 Service 对象 */
	@Autowired
	BankInfoService bankInfoService;

	/** 增 */
	@RequestMapping("add")
	@SaCheckPermission(BankInfo.PERMISSION_CODE_ADD)
	public AjaxJson add(BankInfo b){
		bankInfoService.add(b);
		b = bankInfoService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(b);
	}

	/** 删 */
	@RequestMapping("delete")
	@SaCheckPermission(BankInfo.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 bankInfoService.delete(id);
		return AjaxJson.getSuccess();
	}

	/** 删 - 根据id列表 */
	@RequestMapping("deleteByIds")
	@SaCheckPermission(BankInfo.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		int line = SP.publicMapper.deleteByIds(BankInfo.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}

	/** 改 */
	@RequestMapping("update")
	@SaCheckPermission(BankInfo.PERMISSION_CODE_EDIT)
	public AjaxJson update(BankInfo b){
		bankInfoService.update(b);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */
	@RequestMapping("getById")
		@SaCheckPermission(BankInfo.PERMISSION_CODE)
	public AjaxJson getById(Integer id){
		BankInfo b = bankInfoService.getById(id);
		return AjaxJson.getSuccessData(b);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */
	@RequestMapping("getList")
		@SaCheckPermission(BankInfo.PERMISSION_CODE)
	public AjaxJson getList() {
		SoMap so = SoMap.getRequestSoMap();
		List<BankInfo> list = bankInfoService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}


	@Resource
	private MessageSender messageSender;
	@PostMapping("test")
	public String test(@RequestBody String str){
		StaticLog.info("info:{}",str);
		messageSender.sendToLevelOneMQ(str);
		byte[] key = "90003".getBytes();
		HMac mac = new HMac(HmacAlgorithm.HmacSHA256, key);
		System.out.println(mac.digestBase64("sw10002",false));
		return "hello";
	}




}
